package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TdQuestion;
import com.example.civilizedcity.service.TdQuestionService;

 /**
 * 点位问题;(td_loc_question)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-13
 */
@Api(tags = "点位问题对象功能接口")
@RestController
@RequestMapping("/")
public class TdQuestionController extends BaseController {
    
    @Autowired
    private TdQuestionService tdLocQuestionService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param quId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/tdLocQuestion/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(tdLocQuestionService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/tdLocQuestion")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TdQuestion> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TdLocQuestion> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TdQuestion> result = tdLocQuestionService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param tdLocQuestion 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/tdLocQuestion")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TdQuestion tdLocQuestion) throws Exception {
        tdLocQuestionService.save(tdLocQuestion);
        return ResponseBean.success(tdLocQuestion);
    }
    
    /** 
     * 更新数据
     *
     * @param tdLocQuestion 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/tdLocQuestion/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TdQuestion tdLocQuestion,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        tdLocQuestionService.updateById(tdLocQuestion);
        return ResponseBean.success(tdLocQuestion);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param quId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/tdLocQuestion/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        tdLocQuestionService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}